"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.InstructionsSet = InstructionsSet;
var _eui = require("@elastic/eui");
var _react = _interopRequireDefault(require("react"));
var _reactRouterDom = require("react-router-dom");
var _instruction_variants = require("./instruction_variants");
var _use_apm_params = require("../../../hooks/use_apm_params");
var _url_helpers = require("../../shared/links/url_helpers");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function getTabs(variants) {
  return variants.map(variant => ({
    id: variant.id,
    text: (0, _instruction_variants.getDisplayText)(variant.id)
  }));
}
function InstructionsSet({
  instructions
}) {
  const tabs = getTabs(instructions.instructionVariants);
  const {
    query: {
      agent: agentQuery
    }
  } = (0, _use_apm_params.useApmParams)('/onboarding');
  const history = (0, _reactRouterDom.useHistory)();
  const selectedTab = agentQuery !== null && agentQuery !== void 0 ? agentQuery : tabs[0].id;
  const onSelectedTabChange = agent => {
    (0, _url_helpers.push)(history, {
      query: {
        agent
      }
    });
  };
  const {
    euiTheme
  } = (0, _eui.useEuiTheme)();
  function InstructionTabs({
    agentTabs
  }) {
    return /*#__PURE__*/_react.default.createElement(_eui.EuiTabs, {
      style: {
        padding: `0 ${euiTheme.size.l}`
      }
    }, agentTabs.map(tab => /*#__PURE__*/_react.default.createElement(_eui.EuiTab, {
      key: tab.id,
      isSelected: tab.id === selectedTab,
      onClick: () => onSelectedTabChange(tab.id)
    }, tab.text)));
  }
  function InstructionSteps({
    instructionVariants,
    tab
  }) {
    const selectInstructionSteps = instructionVariants.find(variant => {
      return variant.id === tab;
    });
    if (!selectInstructionSteps) {
      return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null);
    }
    return /*#__PURE__*/_react.default.createElement(_eui.EuiSteps, {
      titleSize: "xs",
      steps: selectInstructionSteps.instructions
    });
  }
  return /*#__PURE__*/_react.default.createElement(_eui.EuiSplitPanel.Outer, null, /*#__PURE__*/_react.default.createElement(_eui.EuiSplitPanel.Inner, {
    color: "subdued",
    paddingSize: "none"
  }, /*#__PURE__*/_react.default.createElement(InstructionTabs, {
    agentTabs: tabs
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiSplitPanel.Inner, {
    paddingSize: "l"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "m"
  }, /*#__PURE__*/_react.default.createElement("h2", null, instructions.title)), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, null), /*#__PURE__*/_react.default.createElement(InstructionSteps, {
    instructionVariants: instructions.instructionVariants,
    tab: selectedTab
  })));
}