"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DegradedFieldTable = void 0;
var _eui = require("@elastic/eui");
var _react = _interopRequireDefault(require("react"));
var _fieldTypes = require("@kbn/field-types");
var _hooks = require("../../../hooks");
var _columns = require("./columns");
var _translations = require("../../../../common/translations");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const DegradedFieldTable = () => {
  const {
    isLoading,
    pagination,
    renderedItems,
    onTableChange,
    sort,
    fieldFormats
  } = (0, _hooks.useDatasetQualityDegradedField)();
  const dateFormatter = fieldFormats.getDefaultInstance(_fieldTypes.KBN_FIELD_TYPES.DATE, [_fieldTypes.ES_FIELD_TYPES.DATE]);
  const columns = (0, _columns.getDegradedFieldsColumns)({
    dateFormatter,
    isLoading
  });
  return /*#__PURE__*/_react.default.createElement(_eui.EuiBasicTable, {
    tableLayout: "fixed",
    columns: columns,
    items: renderedItems !== null && renderedItems !== void 0 ? renderedItems : [],
    loading: isLoading,
    sorting: sort,
    onChange: onTableChange,
    pagination: pagination,
    "data-test-subj": "datasetQualityFlyoutDegradedFieldTable",
    rowProps: {
      'data-test-subj': 'datasetQualityFlyoutDegradedTableRow'
    },
    noItemsMessage: isLoading ? _translations.flyoutDegradedFieldsTableLoadingText : /*#__PURE__*/_react.default.createElement(_eui.EuiEmptyPrompt, {
      "data-test-subj": "datasetQualityFlyoutDegradedTableNoData",
      layout: "vertical",
      title: /*#__PURE__*/_react.default.createElement("h2", null, _translations.flyoutDegradedFieldsTableNoData),
      hasBorder: false,
      titleSize: "m"
    })
  });
};
exports.DegradedFieldTable = DegradedFieldTable;