"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SearchEmbeddableFactory = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _i18n = require("@kbn/i18n");
var _public = require("@kbn/embeddable-plugin/public");
var _constants = require("./constants");
var _embeddable = require("../../common/embeddable");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; } /*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */
class SearchEmbeddableFactory {
  constructor(getStartServices, getDiscoverServices) {
    (0, _defineProperty2.default)(this, "type", _constants.SEARCH_EMBEDDABLE_TYPE);
    (0, _defineProperty2.default)(this, "savedObjectMetaData", {
      name: _i18n.i18n.translate('discover.savedSearch.savedObjectName', {
        defaultMessage: 'Saved search'
      }),
      type: 'search',
      getIconForSavedObject: () => 'discoverApp'
    });
    (0, _defineProperty2.default)(this, "inject", _embeddable.inject);
    (0, _defineProperty2.default)(this, "extract", _embeddable.extract);
    (0, _defineProperty2.default)(this, "isEditable", async () => {
      return (await this.getStartServices()).isEditable();
    });
    (0, _defineProperty2.default)(this, "createFromSavedObject", async (savedObjectId, input, parent) => {
      if (!input.savedObjectId) {
        input.savedObjectId = savedObjectId;
      }
      return this.create(input, parent);
    });
    this.getStartServices = getStartServices;
    this.getDiscoverServices = getDiscoverServices;
  }
  canCreateNew() {
    return false;
  }
  getDisplayName() {
    return _i18n.i18n.translate('discover.embeddable.search.displayName', {
      defaultMessage: 'search'
    });
  }
  async create(input, parent) {
    try {
      const services = await this.getDiscoverServices();
      const {
        executeTriggerActions
      } = await this.getStartServices();
      const {
        SavedSearchEmbeddable: SavedSearchEmbeddableClass
      } = await Promise.resolve().then(() => _interopRequireWildcard(require('./saved_search_embeddable')));
      return new SavedSearchEmbeddableClass({
        editable: Boolean(services.capabilities.discover.save),
        services,
        executeTriggerActions
      }, input, parent);
    } catch (e) {
      console.error(e); // eslint-disable-line no-console
      return new _public.ErrorEmbeddable(e, input, parent);
    }
  }
}
exports.SearchEmbeddableFactory = SearchEmbeddableFactory;