"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createAlertsEsQuery = void 0;
var _common = require("@kbn/data-plugin/common");
var _ruleDataUtils = require("@kbn/rule-data-utils");
var _esQuery = require("@kbn/es-query");
var _common2 = require("@kbn/metrics-data-access-plugin/common");
var _build = require("./build");
var _constants = require("../../components/shared/alerts/constants");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const createAlertsEsQuery = ({
  dateRange,
  assetIds,
  status,
  assetType
}) => {
  const alertStatusFilter = createAlertStatusFilter(status);
  const dateFilter = createDateFilter(dateRange);
  const hostsFilter = (0, _build.buildCombinedAssetFilter)({
    field: (0, _common2.findInventoryFields)(assetType !== null && assetType !== void 0 ? assetType : 'host').id,
    values: assetIds
  });
  const filters = [alertStatusFilter, dateFilter, hostsFilter].filter(Boolean);
  return (0, _esQuery.buildEsQuery)(undefined, [], filters);
};
exports.createAlertsEsQuery = createAlertsEsQuery;
const createDateFilter = date => (0, _common.getTime)(undefined, date, {
  fieldName: _ruleDataUtils.ALERT_TIME_RANGE
});
const createAlertStatusFilter = (status = 'all') => _constants.ALERT_STATUS_QUERY[status] ? {
  query: _constants.ALERT_STATUS_QUERY[status],
  meta: {}
} : null;