"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.combineProcessors = combineProcessors;
var _jsYaml = require("js-yaml");
var _path = require("path");
var _nunjucks = require("nunjucks");
var _util = require("./util");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function combineProcessors(initialPipeline, processors) {
  // Create a deep copy of the initialPipeline to avoid modifying the original input
  const currentPipeline = (0, _util.deepCopy)(initialPipeline);
  if (Object.keys(processors === null || processors === void 0 ? void 0 : processors.processors).length === 0) {
    return currentPipeline;
  }
  // Add the new processors right before the last 2 remove processor in the initial pipeline.
  // This is so all the processors if conditions are not accessing possibly removed fields.
  const currentProcessors = currentPipeline.processors;
  const appendProcessors = createAppendProcessors(processors);
  const combinedProcessors = [...currentProcessors.slice(0, -2), ...appendProcessors, ...currentProcessors.slice(-2)];
  currentPipeline.processors = combinedProcessors;
  return currentPipeline;
}

// The related and categorization graphs returns a simplified array of append processors.
// This function converts the simplified array to the full ESProcessorItem array.
function createAppendProcessors(processors) {
  const templatesPath = (0, _path.join)(__dirname, '../templates/processors');
  const env = new _nunjucks.Environment(new _nunjucks.FileSystemLoader(templatesPath), {
    autoescape: false
  });
  const template = env.getTemplate('append.yml.njk');
  const renderedTemplate = template.render({
    processors
  });
  const appendProcessors = (0, _jsYaml.safeLoad)(renderedTemplate);
  return appendProcessors;
}