"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.StopDatafeedsConfirmModal = void 0;
var _react = _interopRequireWildcard(require("react"));
var _i18nReact = require("@kbn/i18n-react");
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _jobs_utils = require("../../../jobs_utils");
var _utils = require("../utils");
var _managed_jobs_warning_callout = require("./managed_jobs_warning_callout");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const StopDatafeedsConfirmModal = ({
  setShowFunction,
  unsetShowFunction,
  refreshJobs
}) => {
  const [modalVisible, setModalVisible] = (0, _react.useState)(false);
  const [hasManagedJob, setHasManaged] = (0, _react.useState)(true);
  const [jobsToStop, setJobsToStop] = (0, _react.useState)([]);
  const jobIds = (0, _react.useMemo)(() => jobsToStop.map(({
    id
  }) => id), [jobsToStop]);
  (0, _react.useEffect)(() => {
    if (typeof setShowFunction === 'function') {
      setShowFunction(showModal);
    }
    return () => {
      if (typeof unsetShowFunction === 'function') {
        unsetShowFunction();
      }
    };
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  const showModal = (0, _react.useCallback)(jobs => {
    setJobsToStop(jobs);
    if (jobs.some(j => (0, _jobs_utils.isManagedJob)(j))) {
      setModalVisible(true);
      setHasManaged(true);
    }
  }, []);
  const closeModal = (0, _react.useCallback)(() => {
    setModalVisible(false);
    setHasManaged(false);
  }, []);
  if (modalVisible === false) {
    return null;
  }
  if (hasManagedJob) {
    const title = /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.ml.jobsList.stopDatafeedsModal.stopDatafeedsTitle",
      defaultMessage: "Stop datafeed for {jobsCount, plural, one {{jobId}} other {# jobs}}?",
      values: {
        jobsCount: jobIds.length,
        jobId: jobIds[0]
      }
    });
    return /*#__PURE__*/_react.default.createElement(_eui.EuiModal, {
      "data-test-subj": "mlStopDatafeedsConfirmModal",
      onClose: closeModal
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiModalHeader, null, /*#__PURE__*/_react.default.createElement(_eui.EuiModalHeaderTitle, null, title)), /*#__PURE__*/_react.default.createElement(_eui.EuiModalBody, null, /*#__PURE__*/_react.default.createElement(_managed_jobs_warning_callout.ManagedJobsWarningCallout, {
      jobsCount: jobIds.length,
      action: _i18n.i18n.translate('xpack.ml.jobsList.stopDatafeedsModal.stopManagedDatafeedsDescription', {
        defaultMessage: 'stopping'
      })
    })), /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, null), /*#__PURE__*/_react.default.createElement(_eui.EuiModalFooter, null, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonEmpty, {
      onClick: closeModal
    }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.ml.jobsList.stopDatafeedsConfirmModal.cancelButtonLabel",
      defaultMessage: "Cancel"
    })), /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
      onClick: () => {
        (0, _utils.stopDatafeeds)(jobsToStop, refreshJobs);
        closeModal();
      },
      fill: true,
      color: "danger",
      "data-test-subj": "mlStopDatafeedsConfirmModalButton"
    }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.ml.jobsList.stopDatafeedsConfirmModal.stopButtonLabel",
      defaultMessage: "Stop {jobsCount, plural, one {datafeed} other {datafeeds}}",
      values: {
        jobsCount: jobIds.length
      }
    })))));
  } else {
    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null);
  }
};
exports.StopDatafeedsConfirmModal = StopDatafeedsConfirmModal;