"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TimeSeriesExplorerPage = void 0;
var _react = _interopRequireDefault(require("react"));
var _i18n = require("@kbn/i18n");
var _eui = require("@elastic/eui");
var _anomaly_results_view_selector = require("../components/anomaly_results_view_selector");
var _job_selector = require("../components/job_selector");
var _help_menu = require("../components/help_menu");
var _kibana = require("../contexts/kibana");
var _page_header = require("../components/page_header");
var _page_title = require("../components/page_title");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const TimeSeriesExplorerPage = ({
  children,
  dateFormatTz,
  resizeRef,
  noSingleMetricJobsFound
}) => {
  var _presentationUtil$Con, _cases$ui$getCasesCon;
  const {
    services: {
      cases,
      docLinks,
      presentationUtil
    }
  } = (0, _kibana.useMlKibana)();
  const PresentationContextProvider = (_presentationUtil$Con = presentationUtil === null || presentationUtil === void 0 ? void 0 : presentationUtil.ContextProvider) !== null && _presentationUtil$Con !== void 0 ? _presentationUtil$Con : _react.default.Fragment;
  const CasesContext = (_cases$ui$getCasesCon = cases === null || cases === void 0 ? void 0 : cases.ui.getCasesContext()) !== null && _cases$ui$getCasesCon !== void 0 ? _cases$ui$getCasesCon : _react.default.Fragment;
  const casesPermissions = cases === null || cases === void 0 ? void 0 : cases.helpers.canUseCases();
  const helpLink = docLinks.links.ml.anomalyDetection;
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("div", {
    className: "ml-time-series-explorer",
    ref: resizeRef,
    "data-test-subj": "mlPageSingleMetricViewer"
  }, /*#__PURE__*/_react.default.createElement(_page_header.MlPageHeader, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    alignItems: "center",
    gutterSize: "s"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_anomaly_results_view_selector.AnomalyResultsViewSelector, {
    viewId: "timeseriesexplorer"
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_page_title.PageTitle, {
    title: _i18n.i18n.translate('xpack.ml.timeSeriesExplorer.pageTitle', {
      defaultMessage: 'Single Metric Viewer'
    })
  })))), noSingleMetricJobsFound ? null : /*#__PURE__*/_react.default.createElement(_job_selector.JobSelector, {
    dateFormatTz: dateFormatTz,
    singleSelection: true,
    timeseriesOnly: true
  }), /*#__PURE__*/_react.default.createElement(CasesContext, {
    owner: [],
    permissions: casesPermissions
  }, /*#__PURE__*/_react.default.createElement(PresentationContextProvider, null, children)), /*#__PURE__*/_react.default.createElement(_help_menu.HelpMenu, {
    docLink: helpLink
  })));
};
exports.TimeSeriesExplorerPage = TimeSeriesExplorerPage;