"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.updateGlobalNavigation = updateGlobalNavigation;
var _public = require("@kbn/cases-plugin/public");
var _common = require("../../common");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function updateGlobalNavigation({
  capabilities,
  deepLinks,
  updater$
}) {
  const {
    apm,
    logs,
    metrics,
    uptime,
    slo
  } = capabilities.navLinks;
  const someVisible = Object.values({
    apm,
    logs,
    metrics,
    uptime,
    slo
  }).some(visible => visible);
  const updatedDeepLinks = deepLinks.map(link => {
    switch (link.id) {
      case _public.CasesDeepLinkId.cases:
        if (capabilities[_common.casesFeatureId].read_cases) {
          return {
            ...link,
            visibleIn: ['sideNav', 'globalSearch']
          };
        }
        return null;
      case 'alerts':
        if (someVisible) {
          return {
            ...link,
            visibleIn: ['sideNav', 'globalSearch']
          };
        }
        return null;
      case 'rules':
        if (someVisible) {
          return {
            ...link,
            visibleIn: ['sideNav', 'globalSearch']
          };
        }
        return null;
      default:
        return link;
    }
  }).filter(link => link !== null);
  updater$.next(() => ({
    deepLinks: updatedDeepLinks,
    visibleIn: someVisible ? ['sideNav', 'globalSearch', 'home', 'kibanaOverview'] : []
  }));
}