"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.validateRollupIndex = validateRollupIndex;
var _react = _interopRequireDefault(require("react"));
var _i18nReact = require("@kbn/i18n-react");
var _shared_imports = require("../../../../shared_imports");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function validateRollupIndex(rollupIndex, indexPattern) {
  if (!rollupIndex || !rollupIndex.trim()) {
    return [/*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.rollupJobs.create.errors.rollupIndexMissing",
      defaultMessage: "Rollup index is required."
    })];
  }
  if (rollupIndex === indexPattern) {
    return [/*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.rollupJobs.create.errors.rollupIndexSameAsIndexPattern",
      defaultMessage: "Rollup index cannot have the same as the index pattern."
    })];
  }
  const illegalCharacters = _shared_imports.indices.findIllegalCharactersInIndexName(rollupIndex);
  if (illegalCharacters.length) {
    return [/*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.rollupJobs.create.errors.rollupIndexIllegalCharacters",
      defaultMessage: "Remove the characters {characterList} from your rollup index name.",
      values: {
        characterList: /*#__PURE__*/_react.default.createElement("strong", null, illegalCharacters.join(' '))
      }
    })];
  }
  if (rollupIndex.includes(',')) {
    return [/*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.rollupJobs.create.errors.rollupIndexCommas",
      defaultMessage: "Remove the commas from your rollup index name."
    })];
  }
  if (rollupIndex.includes(' ')) {
    return [/*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.rollupJobs.create.errors.rollupIndexSpaces",
      defaultMessage: "Remove the spaces from your rollup index name."
    })];
  }
  if (rollupIndex[0] === '.') {
    return [/*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.rollupJobs.create.errors.rollupIndexBeginningPeriod",
      defaultMessage: "Index names cannot begin with periods."
    })];
  }
  return undefined;
}