"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Dataset = void 0;
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */
/**
 * Options that a plugin/solution provides to rule_registry in order to
 * define and initialize an index for alerts-as-data.
 *
 * IMPORTANT: All names provided in these options are relative. For example:
 * - component template refs will be 'ecs-mappings', not '.alerts-ecs-mappings'
 * - component template names will be 'mappings', not '.alerts-security.alerts-mappings'
 * - etc
 */
/**
 * Dataset suffix restricted to a few values. All alerts-as-data indices
 * are designed to contain only documents of these "kinds".
 */
let Dataset = exports.Dataset = /*#__PURE__*/function (Dataset) {
  Dataset["alerts"] = "alerts";
  Dataset["events"] = "events";
  return Dataset;
}({});
/**
 * When initializing an index, a plugin/solution can break mappings and settings
 * down into several component templates. Some of their properties can be
 * defined by the plugin/solution via these options.
 *
 * https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-component-template.html
 */
/**
 * When initializing an index, a plugin/solution can provide some optional
 * properties which will be included into the index template.
 *
 * Note that:
 * - each index namespace will get its own index template
 * - the template will be created by the library
 * - most of its properties will be set by the library
 * - you can inject some of them via these options
 *
 * https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-put-template.html
 * https://www.elastic.co/guide/en/elasticsearch/reference/current/index-templates.html
 */
/**
 * When initializing an index, a plugin/solution can provide a custom
 * ILM policy that will be applied to concrete indices of this index.
 *
 * Note that policy will be shared between all namespaces of the index.
 */