"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.errorHandler = void 0;
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function isKibanaServerError(error) {
  return error.statusCode && error.message;
}
const errorHandler = logger => handler => {
  return async (context, request, response) => {
    try {
      return await handler(context, request, response);
    } catch (e) {
      logger.error(e);
      if (isKibanaServerError(e)) {
        return response.customError({
          statusCode: e.statusCode,
          body: e.message
        });
      }
      throw e;
    }
  };
};
exports.errorHandler = errorHandler;