"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SearchProfilerUIPlugin = void 0;
var _rxjs = require("rxjs");
var _i18n = require("@kbn/i18n");
var _common = require("../common");
var _locator = require("./locator");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; } /*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */
const checkLicenseStatus = license => {
  const {
    state,
    message
  } = license.check(_common.PLUGIN.id, _common.PLUGIN.minimumLicenseType);
  return state === 'valid' ? {
    valid: true
  } : {
    valid: false,
    message
  };
};
class SearchProfilerUIPlugin {
  setup({
    http,
    getStartServices
  }, {
    devTools,
    home,
    licensing,
    share
  }) {
    home.featureCatalogue.register({
      id: _common.PLUGIN.id,
      title: _i18n.i18n.translate('xpack.searchProfiler.registryProviderTitle', {
        defaultMessage: 'Search Profiler'
      }),
      description: _i18n.i18n.translate('xpack.searchProfiler.registryProviderDescription', {
        defaultMessage: 'Quickly check the performance of any Elasticsearch query.'
      }),
      icon: 'searchProfilerApp',
      path: '/app/dev_tools#/searchprofiler',
      showOnHomePage: false,
      category: 'admin'
    });
    const devTool = devTools.register({
      id: 'searchprofiler',
      title: _i18n.i18n.translate('xpack.searchProfiler.pageDisplayName', {
        defaultMessage: 'Search Profiler'
      }),
      order: 5,
      enableRouting: false,
      mount: async params => {
        const [coreStart] = await getStartServices();
        const {
          notifications,
          analytics,
          i18n: i18nStart,
          theme
        } = coreStart;
        const startServices = {
          analytics,
          i18n: i18nStart,
          theme
        };
        const {
          renderApp
        } = await Promise.resolve().then(() => _interopRequireWildcard(require('./application')));
        const license = await (0, _rxjs.firstValueFrom)(licensing.license$);
        const initialLicenseStatus = checkLicenseStatus(license);
        return renderApp({
          http,
          initialLicenseStatus,
          el: params.element,
          notifications: notifications.toasts,
          location: params.location,
          startServices
        });
      }
    });
    licensing.license$.subscribe(license => {
      if (!checkLicenseStatus(license).valid && !devTool.isDisabled()) {
        devTool.disable();
      } else if (devTool.isDisabled()) {
        devTool.enable();
      }
    });
    share.url.locators.create(new _locator.SearchProfilerLocatorDefinition());
  }
  start() {}
  stop() {}
}
exports.SearchProfilerUIPlugin = SearchProfilerUIPlugin;