"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.localStorageMock = exports.createSecuritySolutionStorageMock = void 0;
var _public = require("@kbn/kibana-utils-plugin/public");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const localStorageMock = () => {
  let store = {};
  return {
    getItem: key => {
      return store[key] || null;
    },
    setItem: (key, value) => {
      store[key] = value;
    },
    clear() {
      store = {};
    },
    removeItem(key) {
      delete store[key];
    }
  };
};
exports.localStorageMock = localStorageMock;
const createStorageMock = storeMock => {
  const storage = new _public.Storage(storeMock);
  return {
    store: storeMock,
    get: jest.fn((...args) => storage.get(...args)),
    clear: jest.fn((...args) => storage.clear(...args)),
    set: jest.fn((...args) => storage.set(...args)),
    remove: jest.fn((...args) => storage.remove(...args))
  };
};
const createSecuritySolutionStorageMock = () => {
  const localStorage = localStorageMock();
  return {
    localStorage,
    storage: createStorageMock(localStorage)
  };
};
exports.createSecuritySolutionStorageMock = createSecuritySolutionStorageMock;