"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TabContentPadding = exports.RuleDetailsFlyout = void 0;
var _react = _interopRequireWildcard(require("react"));
var _styledComponents = _interopRequireDefault(require("styled-components"));
var _css = require("@emotion/css");
var _uiTheme = require("@kbn/ui-theme");
var _eui = require("@elastic/eui");
var _rule_overview_tab = require("./rule_overview_tab");
var _rule_investigation_guide_tab = require("./rule_investigation_guide_tab");
var _constants = require("./constants");
var i18n = _interopRequireWildcard(require("./translations"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const StyledEuiFlyoutBody = (0, _styledComponents.default)(_eui.EuiFlyoutBody)`
  .euiFlyoutBody__overflow {
    display: flex;
    flex: 1;
    overflow: hidden;

    .euiFlyoutBody__overflowContent {
      flex: 1;
      overflow: hidden;
      padding: ${({
  theme
}) => `0 ${theme.eui.euiSizeL} 0`};
    }
  }
`;
const StyledFlexGroup = (0, _styledComponents.default)(_eui.EuiFlexGroup)`
  height: 100%;
`;
const StyledEuiFlexItem = (0, _styledComponents.default)(_eui.EuiFlexItem)`
  &.euiFlexItem {
    flex: 1 0 0;
    overflow: hidden;
  }
`;
const StyledEuiTabbedContent = (0, _styledComponents.default)(_eui.EuiTabbedContent)`
  display: flex;
  flex: 1;
  flex-direction: column;
  overflow: hidden;

  > [role='tabpanel'] {
    display: flex;
    flex: 1;
    flex-direction: column;
    overflow: hidden;
    overflow-y: auto;

    ::-webkit-scrollbar {
      -webkit-appearance: none;
      width: 7px;
    }

    ::-webkit-scrollbar-thumb {
      border-radius: 4px;
      background-color: rgba(0, 0, 0, 0.5);
      -webkit-box-shadow: 0 0 1px rgba(255, 255, 255, 0.5);
    }
  }
`;

/*
 * Fixes tabs to the top and allows the content to scroll.
 */
const ScrollableFlyoutTabbedContent = props => /*#__PURE__*/_react.default.createElement(StyledFlexGroup, {
  direction: "column",
  gutterSize: "none"
}, /*#__PURE__*/_react.default.createElement(StyledEuiFlexItem, {
  grow: true
}, /*#__PURE__*/_react.default.createElement(StyledEuiTabbedContent, props)));
const tabPaddingClassName = (0, _css.css)`
  padding: 0 ${_uiTheme.euiThemeVars.euiSizeM} ${_uiTheme.euiThemeVars.euiSizeXL} ${_uiTheme.euiThemeVars.euiSizeM};
`;
const TabContentPadding = ({
  children
}) => /*#__PURE__*/_react.default.createElement("div", {
  className: tabPaddingClassName
}, children);
exports.TabContentPadding = TabContentPadding;
const RuleDetailsFlyout = ({
  rule,
  ruleActions,
  size = 'm',
  extraTabs = [],
  dataTestSubj,
  id,
  closeFlyout
}) => {
  var _tabs$find;
  const {
    expandedOverviewSections,
    toggleOverviewSection
  } = (0, _rule_overview_tab.useOverviewTabSections)();
  const overviewTab = (0, _react.useMemo)(() => ({
    id: 'overview',
    name: i18n.OVERVIEW_TAB_LABEL,
    content: /*#__PURE__*/_react.default.createElement(TabContentPadding, null, /*#__PURE__*/_react.default.createElement(_rule_overview_tab.RuleOverviewTab, {
      rule: rule,
      columnWidths: size === 'l' ? _constants.LARGE_DESCRIPTION_LIST_COLUMN_WIDTHS : _constants.DEFAULT_DESCRIPTION_LIST_COLUMN_WIDTHS,
      expandedOverviewSections: expandedOverviewSections,
      toggleOverviewSection: toggleOverviewSection
    }))
  }), [rule, size, expandedOverviewSections, toggleOverviewSection]);
  const investigationGuideTab = (0, _react.useMemo)(() => {
    var _rule$note;
    return {
      id: 'investigationGuide',
      name: i18n.INVESTIGATION_GUIDE_TAB_LABEL,
      content: /*#__PURE__*/_react.default.createElement(TabContentPadding, null, /*#__PURE__*/_react.default.createElement(_rule_investigation_guide_tab.RuleInvestigationGuideTab, {
        note: (_rule$note = rule.note) !== null && _rule$note !== void 0 ? _rule$note : ''
      }))
    };
  }, [rule.note]);
  const tabs = (0, _react.useMemo)(() => {
    if (rule.note) {
      return [...extraTabs, overviewTab, investigationGuideTab];
    } else {
      return [...extraTabs, overviewTab];
    }
  }, [overviewTab, investigationGuideTab, rule.note, extraTabs]);
  const [selectedTabId, setSelectedTabId] = (0, _react.useState)(tabs[0].id);
  const selectedTab = (_tabs$find = tabs.find(tab => tab.id === selectedTabId)) !== null && _tabs$find !== void 0 ? _tabs$find : tabs[0];
  (0, _react.useEffect)(() => {
    if (!tabs.find(tab => tab.id === selectedTabId)) {
      // Switch to first tab if currently selected tab is not available for this rule
      setSelectedTabId(tabs[0].id);
    }
  }, [tabs, selectedTabId]);
  const onTabClick = tab => {
    setSelectedTabId(tab.id);
  };
  const prebuiltRulesFlyoutTitleId = (0, _eui.useGeneratedHtmlId)({
    prefix: 'prebuiltRulesFlyoutTitle'
  });
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFlyout, {
    id: id,
    size: size,
    onClose: closeFlyout,
    key: "prebuilt-rules-flyout",
    paddingSize: "l",
    "data-test-subj": dataTestSubj,
    "aria-labelledby": prebuiltRulesFlyoutTitleId,
    ownFocus: true
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlyoutHeader, null, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "m"
  }, /*#__PURE__*/_react.default.createElement("h2", {
    id: prebuiltRulesFlyoutTitleId
  }, rule.name)), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "l"
  })), /*#__PURE__*/_react.default.createElement(StyledEuiFlyoutBody, null, /*#__PURE__*/_react.default.createElement(ScrollableFlyoutTabbedContent, {
    tabs: tabs,
    selectedTab: selectedTab,
    onTabClick: onTabClick
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlyoutFooter, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    justifyContent: "spaceBetween"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonEmpty, {
    onClick: closeFlyout,
    flush: "left"
  }, i18n.DISMISS_BUTTON_LABEL)), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, ruleActions))));
};
exports.RuleDetailsFlyout = RuleDetailsFlyout;