"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateAlertId = void 0;
var _objectHash = _interopRequireDefault(require("object-hash"));
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Generates id for ES|QL alert.
 * Id is generated as hash of event properties and rule/space config identifiers.
 * This would allow to deduplicate alerts, generated from the same event.
 */
const generateAlertId = ({
  event,
  spaceId,
  completeRule,
  tuple,
  isRuleAggregating,
  index
}) => {
  const ruleRunId = tuple.from.toISOString() + tuple.to.toISOString();
  return !isRuleAggregating && event._id ? (0, _objectHash.default)([event._id, event._version, event._index, `${spaceId}:${completeRule.alertId}`]) : (0, _objectHash.default)([ruleRunId, completeRule.ruleParams.query, `${spaceId}:${completeRule.alertId}`, index]);
};
exports.generateAlertId = generateAlertId;