"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.deleteNoteRoute = void 0;
var _securitysolutionEsUtils = require("@kbn/securitysolution-es-utils");
var _constants = require("../../../../../common/constants");
var _route_validation = require("../../../../utils/build_validation/route_validation");
var _utils = require("../../../detection_engine/routes/utils");
var _common = require("../../utils/common");
var _timeline = require("../../../../../common/api/timeline");
var _notes = require("../../saved_object/notes");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const deleteNoteRoute = (router, config, security) => {
  router.versioned.delete({
    path: _constants.NOTE_URL,
    options: {
      tags: ['access:securitySolution']
    },
    access: 'public'
  }).addVersion({
    validate: {
      request: {
        body: (0, _route_validation.buildRouteValidationWithExcess)(_timeline.deleteNoteSchema)
      }
    },
    version: '2023-10-31'
  }, async (context, request, response) => {
    const siemResponse = (0, _utils.buildSiemResponse)(response);
    try {
      var _request$body$noteId, _request$body, _request$body$noteIds, _request$body2;
      const frameworkRequest = await (0, _common.buildFrameworkRequest)(context, security, request);
      const noteId = (_request$body$noteId = (_request$body = request.body) === null || _request$body === void 0 ? void 0 : _request$body.noteId) !== null && _request$body$noteId !== void 0 ? _request$body$noteId : '';
      const noteIds = (_request$body$noteIds = (_request$body2 = request.body) === null || _request$body2 === void 0 ? void 0 : _request$body2.noteIds) !== null && _request$body$noteIds !== void 0 ? _request$body$noteIds : null;
      if (noteIds != null) {
        await (0, _notes.deleteNote)({
          request: frameworkRequest,
          noteIds
        });
        return response.ok({
          body: {
            data: {}
          }
        });
      } else {
        await (0, _notes.deleteNote)({
          request: frameworkRequest,
          noteIds: [noteId]
        });
        return response.ok({
          body: {
            data: {}
          }
        });
      }
    } catch (err) {
      const error = (0, _securitysolutionEsUtils.transformError)(err);
      return siemResponse.error({
        body: error.message,
        statusCode: error.statusCode
      });
    }
  });
};
exports.deleteNoteRoute = deleteNoteRoute;