"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDeleteSloInstance = useDeleteSloInstance;
var _i18n = require("@kbn/i18n");
var _reactQuery = require("@tanstack/react-query");
var _kibana_react = require("../utils/kibana_react");
var _query_key_factory = require("./query_key_factory");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function useDeleteSloInstance() {
  const {
    http,
    notifications: {
      toasts
    }
  } = (0, _kibana_react.useKibana)().services;
  const queryClient = (0, _reactQuery.useQueryClient)();
  return (0, _reactQuery.useMutation)(['deleteSloInstance'], ({
    slo,
    excludeRollup
  }) => {
    try {
      return http.post(`/api/observability/slos/_delete_instances`, {
        body: JSON.stringify({
          list: [{
            sloId: slo.id,
            instanceId: slo.instanceId,
            excludeRollup
          }]
        })
      });
    } catch (error) {
      return Promise.reject(`Something went wrong: ${String(error)}`);
    }
  }, {
    onError: (error, {
      slo
    }) => {
      var _error$body$message, _error$body;
      toasts.addError(new Error((_error$body$message = (_error$body = error.body) === null || _error$body === void 0 ? void 0 : _error$body.message) !== null && _error$body$message !== void 0 ? _error$body$message : error.message), {
        title: _i18n.i18n.translate('xpack.slo.deleteInstance.errorNotification', {
          defaultMessage: 'Failed to delete {name} [instance: {instanceId}]',
          values: {
            name: slo.name,
            instanceId: slo.instanceId
          }
        })
      });
    },
    onSuccess: (_data, {
      slo
    }) => {
      queryClient.invalidateQueries({
        queryKey: _query_key_factory.sloKeys.lists(),
        exact: false
      });
      toasts.addSuccess(_i18n.i18n.translate('xpack.slo.slo.deleteInstance.successNotification', {
        defaultMessage: 'Deleted {name} [instance: {instanceId}]',
        values: {
          name: slo.name,
          instanceId: slo.instanceId
        }
      }));
    }
  });
}