"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.renderLegendItem = exports.WaterfallChartWrapper = void 0;
var _react = _interopRequireWildcard(require("react"));
var _useLocalStorage = _interopRequireDefault(require("react-use/lib/useLocalStorage"));
var _eui = require("@elastic/eui");
var _use_date_format = require("../../../../../../hooks/use_date_format");
var _data_formatting = require("../../common/network_data/data_formatting");
var _use_flyout = require("./waterfall_flyout/use_flyout");
var _waterfall_flyout = require("./waterfall_flyout/waterfall_flyout");
var _waterfall_sidebar_item = require("./waterfall_sidebar_item");
var _waterfall_context = require("./context/waterfall_context");
var _waterfall_chart = require("./waterfall_chart");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const renderLegendItem = item => {
  return /*#__PURE__*/_react.default.createElement(_eui.EuiHealth, {
    color: item.color,
    className: "eui-textNoWrap"
  }, item.name);
};
exports.renderLegendItem = renderLegendItem;
const WaterfallChartWrapper = ({
  data,
  total,
  markerItems,
  activeStep
}) => {
  const [query, setQuery] = (0, _react.useState)('');
  const [activeFilters, setActiveFilters] = (0, _react.useState)([]);
  const [onlyHighlighted, setOnlyHighlighted] = (0, _useLocalStorage.default)('xpack.synthetics.waterfallChart.showOnlyHighlighted', false);
  const [showCustomMarks, setShowCustomMarks] = (0, _useLocalStorage.default)('xpack.synthetics.waterfallChart.showCustomMarks', false);
  const [networkData] = (0, _react.useState)(data);
  const hasFilters = activeFilters.length > 0;
  const dateFormatter = (0, _use_date_format.useDateFormat)();
  const {
    series,
    domain,
    metadata,
    totalHighlightedRequests
  } = (0, _react.useMemo)(() => {
    return (0, _data_formatting.getSeriesAndDomain)(networkData, onlyHighlighted, dateFormatter, query, activeFilters, markerItems);
  }, [networkData, dateFormatter, query, activeFilters, onlyHighlighted, markerItems]);
  const sidebarItems = (0, _react.useMemo)(() => {
    return (0, _data_formatting.getSidebarItems)(networkData, onlyHighlighted !== null && onlyHighlighted !== void 0 ? onlyHighlighted : false, query, activeFilters);
  }, [networkData, query, activeFilters, onlyHighlighted]);
  const {
    flyoutData,
    onBarClick,
    onProjectionClick,
    onSidebarClick,
    isFlyoutVisible,
    onFlyoutClose
  } = (0, _use_flyout.useFlyout)(metadata);
  const renderFlyout = (0, _react.useCallback)(() => {
    return /*#__PURE__*/_react.default.createElement(_waterfall_flyout.WaterfallFlyout, {
      flyoutData: flyoutData,
      onFlyoutClose: onFlyoutClose,
      isFlyoutVisible: isFlyoutVisible
    });
  }, [flyoutData, isFlyoutVisible, onFlyoutClose]);
  const highestSideBarIndex = Math.max(...series.map(sr => sr.x));
  const renderSidebarItem = (0, _react.useCallback)(item => {
    return /*#__PURE__*/_react.default.createElement(_waterfall_sidebar_item.WaterfallSidebarItem, {
      item: item,
      renderFilterScreenReaderText: hasFilters && !onlyHighlighted,
      onClick: onSidebarClick,
      highestIndex: highestSideBarIndex
    });
  }, [hasFilters, onlyHighlighted, onSidebarClick, highestSideBarIndex]);
  return /*#__PURE__*/_react.default.createElement(_waterfall_context.WaterfallProvider, {
    activeStep: activeStep,
    markerItems: markerItems,
    totalNetworkRequests: total,
    fetchedNetworkRequests: networkData.length,
    highlightedNetworkRequests: totalHighlightedRequests,
    data: series,
    onElementClick: (0, _react.useCallback)(onBarClick, [onBarClick]),
    onProjectionClick: (0, _react.useCallback)(onProjectionClick, [onProjectionClick]),
    onSidebarClick: onSidebarClick,
    showOnlyHighlightedNetworkRequests: onlyHighlighted !== null && onlyHighlighted !== void 0 ? onlyHighlighted : false,
    showCustomMarks: showCustomMarks !== null && showCustomMarks !== void 0 ? showCustomMarks : false,
    sidebarItems: sidebarItems,
    metadata: metadata,
    activeFilters: activeFilters,
    setActiveFilters: setActiveFilters,
    setOnlyHighlighted: setOnlyHighlighted,
    setShowCustomMarks: setShowCustomMarks,
    query: query,
    setQuery: setQuery,
    renderTooltipItem: (0, _react.useCallback)(tooltipProps => {
      return /*#__PURE__*/_react.default.createElement(_eui.EuiHealth, {
        color: String(tooltipProps === null || tooltipProps === void 0 ? void 0 : tooltipProps.colour)
      }, tooltipProps === null || tooltipProps === void 0 ? void 0 : tooltipProps.value);
    }, [])
  }, /*#__PURE__*/_react.default.createElement(_waterfall_chart.WaterfallChart, {
    tickFormat: (0, _react.useCallback)(d => `${Number(d).toFixed(0)} ms`, []),
    domain: domain,
    barStyleAccessor: (0, _react.useCallback)(({
      datum
    }) => {
      var _datum$config;
      if (!((_datum$config = datum.config) !== null && _datum$config !== void 0 && _datum$config.isHighlighted)) {
        var _datum$config2;
        return {
          rect: {
            fill: (_datum$config2 = datum.config) === null || _datum$config2 === void 0 ? void 0 : _datum$config2.colour,
            opacity: '0.1'
          }
        };
      }
      return datum.config.colour;
    }, []),
    renderSidebarItem: renderSidebarItem,
    renderLegendItem: renderLegendItem,
    renderFlyout: renderFlyout
  }));
};
exports.WaterfallChartWrapper = WaterfallChartWrapper;