"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MathAgg = MathAgg;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _agg_row = require("./agg_row");
var _agg_select = require("./agg_select");
var _create_change_handler = require("../lib/create_change_handler");
var _create_select_handler = require("../lib/create_select_handler");
var _create_text_handler = require("../lib/create_text_handler");
var _vars = require("./vars");
var _eui = require("@elastic/eui");
var _i18nReact = require("@kbn/i18n-react");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */

const checkModel = model => Array.isArray(model.variables) && model.script !== undefined;
function MathAgg(props) {
  const {
    siblings,
    model,
    fields,
    indexPattern
  } = props;
  const htmlId = (0, _eui.htmlIdGenerator)();
  const handleChange = (0, _create_change_handler.createChangeHandler)(props.onChange, model);
  const handleSelectChange = (0, _create_select_handler.createSelectHandler)(handleChange);
  const handleTextChange = (0, _create_text_handler.createTextHandler)(handleChange);
  (0, _react.useEffect)(() => {
    if (!checkModel(model)) {
      handleChange({
        variables: [(0, _vars.newVariable)()],
        script: ''
      });
    }
  }, [handleChange, model]);
  return /*#__PURE__*/_react.default.createElement(_agg_row.AggRow, {
    disableDelete: props.disableDelete,
    model: props.model,
    onAdd: props.onAdd,
    onDelete: props.onDelete,
    siblings: props.siblings,
    dragHandleProps: props.dragHandleProps
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "column",
    gutterSize: "l"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFormLabel, {
    htmlFor: htmlId('aggregation')
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "visTypeTimeseries.math.aggregationLabel",
    defaultMessage: "Aggregation"
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "xs"
  }), /*#__PURE__*/_react.default.createElement(_agg_select.AggSelect, {
    id: htmlId('aggregation'),
    siblings: props.siblings,
    value: model.type,
    panelType: props.panel.type,
    onChange: handleSelectChange('type')
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFormLabel, {
    htmlFor: htmlId('variables')
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "visTypeTimeseries.math.variablesLabel",
    defaultMessage: "Variables"
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "xs"
  }), /*#__PURE__*/_react.default.createElement(_vars.CalculationVars, {
    id: htmlId('variables'),
    metrics: siblings,
    fields: fields,
    indexPattern: indexPattern,
    onChange: handleChange,
    name: "variables",
    model: model,
    includeSiblings: true
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
    id: "mathExpressionInput",
    label: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "visTypeTimeseries.math.expressionLabel",
      defaultMessage: "Expression"
    }),
    fullWidth: true,
    helpText: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "visTypeTimeseries.math.expressionDescription",
      defaultMessage: "This field uses basic math expressions (see {link}) - Variables are keys on the {params} object, i.e. {paramsName} To access all the data use {paramsValues} for an array of the values and {paramsTimestamps} for an array of the timestamps. {paramsTimestamp} is available for the current bucket's timestamp, {paramsIndex} is available for the current bucket's index, and {paramsInterval}s available for the interval in milliseconds.",
      values: {
        link: /*#__PURE__*/_react.default.createElement(_eui.EuiLink, {
          href: "https://github.com/elastic/kibana/blob/main/packages/kbn-tinymath/docs/functions.md",
          target: "_blank"
        }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
          id: "visTypeTimeseries.math.expressionDescription.tinyMathLinkText",
          defaultMessage: "TinyMath"
        })),
        params: /*#__PURE__*/_react.default.createElement(_eui.EuiCode, null, "params"),
        paramsName: /*#__PURE__*/_react.default.createElement(_eui.EuiCode, null, "params.<name>"),
        paramsValues: /*#__PURE__*/_react.default.createElement(_eui.EuiCode, null, "params._all.<name>.values"),
        paramsTimestamps: /*#__PURE__*/_react.default.createElement(_eui.EuiCode, null, "params._all.<name>.timestamps"),
        paramsTimestamp: /*#__PURE__*/_react.default.createElement(_eui.EuiCode, null, "params._timestamp"),
        paramsIndex: /*#__PURE__*/_react.default.createElement(_eui.EuiCode, null, "params._index"),
        paramsInterval: /*#__PURE__*/_react.default.createElement(_eui.EuiCode, null, "params._interval")
      }
    })
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiTextArea, {
    "data-test-subj": "mathExpression",
    onChange: handleTextChange('script'),
    fullWidth: true,
    value: model.script
  })))));
}
MathAgg.propTypes = {
  disableDelete: _propTypes.default.bool,
  fields: _propTypes.default.object,
  indexPattern: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.object]),
  model: _propTypes.default.object,
  onAdd: _propTypes.default.func,
  onChange: _propTypes.default.func,
  onDelete: _propTypes.default.func,
  panel: _propTypes.default.object,
  series: _propTypes.default.object,
  siblings: _propTypes.default.array
};